@@ -7,7 +7,6 @@ package Dancer::Helpers;
 use strict;
 use warnings;
 
-use CGI;
 use Dancer::Response;
 use Dancer::Config 'setting';
 use Dancer::FileUtils 'path';
@@ -18,11 +17,8 @@ use Dancer::Template;
 sub send_file { 
     my ($path) = @_;
 
-    # Fake the CGI request with /path/to/file
-    my $request = CGI->new;
-    $request->path_info($path);
-    $request->request_method('GET');
-    Dancer::SharedData->cgi($request);
+    my $request = Dancer::Request->new_for_request('GET' => $path);
+    Dancer::SharedData->request($request);
 
     my $resp = Dancer::Renderer::get_file_response();
     return $resp if $resp;
@@ -44,7 +40,7 @@ sub template {
 
     $tokens ||= {};
     $tokens->{params} = Dancer::SharedData::params();
-    $tokens->{request} = Dancer::SharedData->cgi;
+    $tokens->{request} = Dancer::SharedData->request;
     
     my $content = Dancer::Template->engine->render($view, $tokens);
     return $content if not defined $layout;
