@@ -3,10 +3,6 @@ package Dancer::Template;
 use strict;
 use warnings;
 
-# supported template engines
-use Dancer::Template::Simple;
-use Dancer::Template::TemplateToolkit;
-
 # singleton for the current template engine
 my $engine;
 sub engine { $engine }
@@ -15,12 +11,16 @@ sub engine { $engine }
 sub init {
     my ($self, $setting, $config) = @_;
     if ((not defined $setting) or ($setting eq 'simple')) {
+        require Dancer::Template::Simple;
         return $engine = Dancer::Template::Simple->new;
     }
     elsif ($setting eq 'template_toolkit') {
+        require Dancer::Template::TemplateToolkit;
         return $engine = Dancer::Template::TemplateToolkit->new(settings => $config);
-    }
-    else {
+    }elsif($setting eq 'micro_template') {
+        require Dancer::Template::MicroTemplate;
+        return $engine = Dancer::Template::MicroTemplate->new(settings => $config);
+    }else {
         die "unknown template engine '$setting'";
     }
 }
